@@ -43,6 +43,16 @@ class tree_overview(base_subcomponent, base_draggable, QtWidgets.QTreeWidget):
 
 	structure_change = QtCore.Signal()
 	text_change = QtCore.Signal()
+	
+	NAVIGATION_KEYS = [
+		QtCore.Qt.Key_Up,
+		QtCore.Qt.Key_Down,
+		QtCore.Qt.Key_PageUp,
+		QtCore.Qt.Key_PageDown,
+		QtCore.Qt.Key_Home,
+		QtCore.Qt.Key_End,
+		QtCore.Qt.Key_Return
+	]
 
 	def __init__(self, main_window, overview_mode=True):
 
@@ -756,7 +766,22 @@ class tree_overview(base_subcomponent, base_draggable, QtWidgets.QTreeWidget):
 				if isinstance(parent_item, sequence):
 					break
 				target_treeitem = parent_treeitem
-			index = parent_treeitem.indexOfChild(target_treeitem)+1
+			index = parent_treeitem.indexOfChild(target_treeitem) + 1
+			# Below we correct the index when an item is moved down in the same
+			# sequence. In this case, the item is first removed from the
+			# sequence (in drop_event_item_existing) and because the treewidget
+			# is not refreshed, the index as returned by the parent_treeitem
+			# is one too high. (This is clearly a hack, but it seems to work.)
+			children = parent_item.direct_children()
+			if len(children) > 1:
+				try:
+					if (
+						children[index - 1] != target_item.name and
+						children[index - 2] == target_item.name
+					):
+						index -= 1
+				except IndexError:
+					pass
 			parent_item.insert_child_item(item.name, index=index)
 		if e is not None:
 			e.accept()
@@ -778,6 +803,11 @@ class tree_overview(base_subcomponent, base_draggable, QtWidgets.QTreeWidget):
 				type:	QDragLeaveEvent
 		"""
 
+		# The focusOutEvent arrives too late, so here we explictly give the
+		# currently opened item the opportunity to get ready
+		item_name = self.tabwidget.current_item()
+		if item_name is not None:
+			self.item_store[item_name].get_ready()
 		data = drag_and_drop.receive(e)
 		if data[u'type'] == u'item-snippet':
 			self.drop_event_item_new(data, e)
@@ -892,25 +922,23 @@ class tree_overview(base_subcomponent, base_draggable, QtWidgets.QTreeWidget):
 		e -- a QKeyEvent
 		"""
 
-		if self.currentItem() is None:
-			return
 		super(tree_overview, self).keyPressEvent(e)
+		current_item = self.currentItem()
+		if current_item is None:
+			return
 		# In overview mode, navigating through the items causes tabs to be
 		# opened
 		if self.overview_mode:
-			if e.key() in [QtCore.Qt.Key_Up, QtCore.Qt.Key_Down,
-					QtCore.Qt.Key_PageUp, QtCore.Qt.Key_PageDown,
-					QtCore.Qt.Key_Home, QtCore.Qt.Key_End,
-					QtCore.Qt.Key_Return]:
-				self.currentItem().open_tab()
+			if e.key() in self.NAVIGATION_KEYS:
+				current_item.open_tab()
 			return
 		# In sequence view, the run-if statements can be changed using
 		# Control+Plus (always) and Control+Minus (never)
 		if QtCore.Qt.ControlModifier & e.modifiers():
 			if e.key() == QtCore.Qt.Key_Minus:
-				self.currentItem().setText(1, u'never')
+				current_item.setText(1, u'never')
 			elif e.key() in [QtCore.Qt.Key_Plus, QtCore.Qt.Key_Equal]:
-				self.currentItem().setText(1, u'always')
+				current_item.setText(1, u'always')
 
 	def recursive_children(self, item):
 
